SECRET_KEY = "s"
WSGI_APPLICATION = "django_pyuwsgi.tests.django_settings.application"
INSTALLED_APPS = ["django_pyuwsgi"]
ROOT_URLCONF = "django_pyuwsgi.tests.django_settings"
STATIC_URL = "/static/"
STATIC_ROOT = "/tmp/static"

urlpatterns = []
from django.core.wsgi import get_wsgi_application

application = get_wsgi_application()



from __future__ import absolute_import

from django.conf import settings
from django.core.management import BaseCommand

import pyuwsgi


def get_default_args():
    """Load pyuwsgi args from settings or use our defaults"""
    try:
        return settings.PYUWSGI_ARGS
    except AttributeError:
        defaults = [
            "--strict",
            "--need-app",
            # project.wsgi.application -> project.wsgi:application
            "--module={}".format(":".join(settings.WSGI_APPLICATION.rsplit(".", 1))),
        ]
        if (settings.STATIC_URL or "").startswith("/"):
            defaults.extend(
                [
                    "--static-map",
                    "{}={}".format(
                        settings.STATIC_URL.rstrip("/"), settings.STATIC_ROOT
                    ),
                ]
            )
        return defaults


class Command(BaseCommand):
    """
    This bypasses any Django handling of the command and sends all arguments straight
    to pyuwsgi.
    """

    help = "Start pyuwsgi server"

    def run_from_argv(self, argv):
        args = get_default_args() + argv[2:]
        pyuwsgi.run(*args)

    def execute(self, *args, **options):
        self.run_from_argv(["manage.py", "pyuwsgi"] + list(args))



import os
import subprocess
import sys
import time

from django.test import override_settings

from django_pyuwsgi.management.commands.pyuwsgi import get_default_args

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "django_pyuwsgi.tests.django_settings")


def _args_to_str(args):
    """Turn a list of strings into a string that can be used as function args"""
    return ", ".join(["'{}'".format(a.replace("'", "'")) for a in args])


def run_django(*args):
    # timeout isn't supported in Python 2.7, do it the hard way...
    proc = subprocess.Popen(
        [
            sys.executable,
            "-c",
            "from django_pyuwsgi.management.commands.pyuwsgi import Command; "
            "Command().execute({})".format(_args_to_str(args)),
        ],
        stdout=subprocess.PIPE,
        stderr=subprocess.STDOUT,
    )
    time.sleep(1)
    proc.kill()
    return proc


def test_django():
    """Start a Django HTTP server and then kill it"""
    proc = run_django("--http-socket=127.0.0.1:0")
    assert "WSGI app 0 (mountpoint='') ready in" in proc.communicate()[0].decode(
        "utf-8"
    )


def test_default_args():
    assert get_default_args() == [
        "--strict",
        "--need-app",
        "--module=django_pyuwsgi.tests.django_settings:application",
        "--static-map",
        "/static=/tmp/static",
    ]


@override_settings(PYUWSGI_ARGS=["--master", "--thunder-lock"])
def test_settings_args():
    assert get_default_args() == ["--master", "--thunder-lock"]



import os

from setuptools import find_packages, setup


README = open(os.path.join(os.path.dirname(__file__), "README.md")).read()

setup(
    name="django-pyuwsgi",
    version="1.1.0",
    description="uWSGI as a Django management command",
    author="Peter Baumgartner",
    author_email="pete@lincolnloop.com",
    url="https://github.com/lincolnloop/django-pyuwsgi",
    long_description=README,
    long_description_content_type="text/markdown",
    keywords=["uwsgi", "django", "pyuwsgi"],
    packages=find_packages(),
    license="MIT",
    install_requires=["pyuwsgi>=2.0.17.2b3", "Django"],
    extras_require={"test": ["pytest"]},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Framework :: Django",
    ],
)
